package com.idiot.operationbackend.controller;

import com.baomidou.kaptcha.Kaptcha;
import com.idiot.operationbackend.entity.AuthUser;
import com.idiot.operationbackend.service.facade.AuthUserService;
import com.idiot.operationbackend.support.CustomException;
import com.idiot.operationbackend.support.JsonResult;
import com.idiot.operationbackend.util.JwtTokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Objects;

/**
 * @author wang xiao
 * @date Created in 15:06 2020/9/10
 */
@RestController
@RequestMapping("/auth")
@Api(value = "AuthController", tags ="认证、授权登录")
public class AuthController {


    private final Logger logger = LoggerFactory.getLogger(AuthController.class);

    @Autowired
    private Kaptcha kaptcha;

    @Autowired
    private AuthUserService userService;


    @GetMapping("/captcha")
    @ApiOperation(value = "获取验证码")
    public void getCaptcha() {
        kaptcha.render();
    }



    @PostMapping("/login")
    @ApiOperation(value = "账号登录")
    @ApiImplicitParam(value = "authUser",paramType = "body",dataTypeClass = AuthUser.class)
    public ResponseEntity<JsonResult<AuthUser>> login(@RequestBody @Valid AuthUser authUser) {
        logger.info("用户：{}账号密码登录",authUser.getUserCode());
        String captchaCode = authUser.getCaptchaCode();
        kaptcha.validate(captchaCode);
        authUser =userService.queryByUserCodeAndPassword(authUser.getPassword(),authUser.getUserCode());
        if (Objects.isNull(authUser)) {
            throw new CustomException(500,"账号或者密码错误！请检查大小写");
        }
        authUser.setPassword("");
        String  token = JwtTokenUtil.sign(authUser.getNikeName(),authUser.getId());
        return ResponseEntity.ok().header("AUTH_TOKEN",token)
                .body(JsonResult.success(authUser));
    }
}
