package com.idiot.operationbackend.controller;

import com.idiot.operationbackend.config.PlatformProperties;
import com.idiot.operationbackend.service.facade.WeChatService;
import com.idiot.operationbackend.support.Constants;
import com.idiot.operationbackend.support.JsonResult;
import com.idiot.operationbackend.support.wechat.WXBizMsgCrypt;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;



/**
 * @author wang xiao
 * @date Created in 10:38 2020/9/11
 */
@RestController
@RequestMapping("/wechat")
@Api(value = "WeChatController", tags ="微信")
public class WeChatController {

    private final Logger logger = LoggerFactory.getLogger(WeChatController.class);


    @Autowired
    private WeChatService weChatService;


    @GetMapping("preAuth")
    @ApiOperation(value = "获取预授权码地址，微信认证公众号")
    public ResponseEntity<JsonResult<String>> getPreAuthUrl ()   {
        return ResponseEntity.ok(JsonResult.success(weChatService.getPreAuthUrl()));
    }




    @PostMapping("/notice")
    @ApiOperation(value = "验证票据接受url")
    public String noticeCallBack(HttpServletRequest request)  {
        String nonce = request.getParameter("nonce");
        String timestamp = request.getParameter("timestamp");
        // 默认aes
        String encryptType = request.getParameter("encrypt_type");
        String msgSignature = request.getParameter("msg_signature");
        logger.info("验证票据事件,param参数依次是nonce:{},timestamp:{},encrypt_type:{},msg_signature:{}",nonce,
                timestamp,encryptType,msgSignature);
        try {
            BufferedInputStream bis = new BufferedInputStream(request.getInputStream());
            ByteArrayOutputStream buf = new ByteArrayOutputStream();
            int result = bis.read();
            while(result != -1) {
                buf.write((byte) result);
                result = bis.read();
            }
            String postData = buf.toString("utf-8");
            logger.info("微信验证票据回调,postData before decry :{}",postData);
            postData = weChatService.decryptMsg(msgSignature,timestamp,nonce,postData);
            logger.info("微信验证票据回调,postData after decry :{}",postData);
            return weChatService.notice(weChatService.xmlToMap(postData));
        }catch (Exception e) {
            logger.info("微信验证票据回调 ------->失败,message is :{}",e.getMessage());
            return Constants.SUCCESS;
        }
    }


    @PostMapping("/authCallBack")
    @ApiOperation(value = "授权地址回调")
    public String authCallBack(HttpServletRequest request)  {
        return "";
    }


}
