package com.idiot.operationbackend.service.facade;

import com.idiot.operationbackend.support.Constants;
import com.idiot.operationbackend.support.wechat.AesException;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.springframework.util.StringUtils;

import java.io.InputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 微信处理
 * @author wang xiao
 * @date Created in 10:53 2020/9/11
 */
public interface WeChatService {

  /**
   *  授权回调
   * @author wangxiao
   * @date 14:17 2020/9/11
   * @param param
   * @return java.lang.String
   */
    String notice(Map<String,String> param);


  /**
   * 不支持的消息
   * @author wangxiao
   * @date 15:27 2020/7/1
   * @param param
   * @return java.lang.String
   */
  default String unSupportedMessage(Map<String,String> param) {
    return Constants.SUCCESS;
  }



  /**
   *  获取令牌
   * @author wangxiao
   * @date 17:25 2020/9/11
   * @param
   * @return java.lang.String
   */
  String getComponentAccessToken ();


  /**
   *  获取预授权码
   * @author wangxiao
   * @date 18:10 2020/9/11
   * @return java.lang.String
   */
  String getPreAuthCode ();


  /**
   *  获取预授权地址
   * @author wangxiao
   * @date 19:34 2020/9/11
   * @param
   * @return java.lang.String
   */
  String getPreAuthUrl ();



  /**
   *  微信解密数据
   * @author wangxiao
   * @date 19:41 2020/9/11
   * @param msgSignature
   * @param timestamp
   * @param nonce
   * @param data
   * @return java.lang.String
   */
  String decryptMsg(String msgSignature,String timestamp,String nonce,String data);


  /**
   *  微信加密数据
   * @author wangxiao
   * @date 19:49 2020/9/11
   * @param data
   * @return java.lang.String
   */
  String encryptMsg(String data);



  /**
   *  微信消息转换成map(非加密)
   * @author wangxiao
   * @date 14:10 2020/9/11
   * @param inputStream
   * @return java.util.Map<java.lang.String,java.lang.String>
   */
  default Map<String, String> xmlToMap(InputStream inputStream) {
    SAXReader saxReader = new SAXReader();
    try {
      Document document = saxReader.read(inputStream);
      return parseDocument(document);
    }catch (Exception e) {
      return null;
    }
  }


  /**
   *  微信消息转换成map(非加密)
   * @author wangxiao
   * @date 14:10 2020/9/11
   * @param data
   * @return java.util.Map<java.lang.String,java.lang.String>
   */
  default Map<String, String> xmlToMap(String data) {
    if (StringUtils.isEmpty(data)) {
      return null;
    }
    SAXReader saxReader = new SAXReader();
    try {
      Document document = saxReader.read(data);
      return parseDocument(document);
    }catch (Exception e) {
      return null;
    }
  }

  /**
   *  document 转 map
   * @author wangxiao
   * @date 19:36 2020/9/11
   * @param document
   * @return java.util.Map<java.lang.String,java.lang.String>
   */
  default Map<String,String> parseDocument (Document document) {
    Map<String, String> map = new HashMap<>(10);
    Element root = document.getRootElement();
    List<Element> elements = root.elements();
    for (Element element : elements) {
      map.put(element.getName(), element.getStringValue());
    }
    return map;
  }

}
